[![Python test and package](https://github.com/openaleph/openaleph-procrastinate/actions/workflows/python.yml/badge.svg)](https://github.com/openaleph/openaleph-procrastinate/actions/workflows/python.yml)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)
[![Coverage Status](https://coveralls.io/repos/github/openaleph/openaleph-procrastinate/badge.svg?branch=main)](https://coveralls.io/github/openaleph/openaleph-procrastinate?branch=main)
[![AGPLv3+ License](https://img.shields.io/pypi/l/openaleph-procrastinate)](./LICENSE)

# OpenAleph Procrastinate

The most dumbest task queue for [OpenAleph](https://openaleph.org) based on [procrastinate](https://procrastinate.readthedocs.io/en/stable/)

## Documentation

https://openaleph.org/docs/lib/openaleph-procrastinate

## License and Copyright

`openaleph-procrastinate`, (C) 2025 [Data and Research Center – DARC](https://dataresearchcenter.org)

`openaleph-procrastinate` is licensed under the AGPLv3 or later license.

see [NOTICE](./NOTICE) and [LICENSE](./LICENSE)
